package ingest

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io/ioutil"
	"log"
	"net/http"
)

type RequestPayload struct {
	CachePath string `json:"cache_path"`
	CalSpl    string `json:"cal_spl"`
}

/**
 * Call the SECI ingestion endpoint to initiate the workflow
 *
 * @param img_set_path A string with the path to a VLASS image set
 * @param locator A string with the locator for the image set
 * @param capo_profile A string with the path to the CAPO property file used to
 * get the Workflow service URL
 **/
func CallIngestionEndpoint(img_set_path string, locator string, capo_profile string) {
	payload := RequestPayload{
		CachePath: img_set_path,
		CalSpl:    locator,
	}

	// Convert payload to json
	payload_json, err := json.Marshal(payload)
	checkError(err)

	fmt.Println(string(payload_json))

	// Get post request
	workflow_url_prop := "edu.nrao.workspaces.WorkflowSettings.serviceUrl"
	workflow_url := getCapoProperty(capo_profile, workflow_url_prop)
	post_url := workflow_url + "/workflows/requests/vlass_ingest/seci"

	resp, err := http.Post(post_url, "application/json", bytes.NewBuffer(payload_json))
	checkError(err)

	defer resp.Body.Close()

	if resp.StatusCode != http.StatusOK {
		panic(fmt.Sprintf("Error making POST request to URL %s, got status code %d", post_url, resp.StatusCode))
	}

	resp_header := resp.Header
	resp_body, err := ioutil.ReadAll(resp.Body)
	checkError(err)

	log.Println("POST Request Made")
	log.Println("Response Headers: ", resp_header)
	log.Println("Response Body: ", resp_body)
}
