#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from sqlalchemy import text

from .schema import create_session
from .schema.pstmodel import Author, Person, Proposal, UserAuthentication

session = create_session("PST")


def getproposal(telescope, proposalcode):
    code = f"%{proposalcode}%"

    if telescope == "VLBA":
        proposal = (
            session.query(Proposal)
            .filter(Proposal.TELESCOPE == telescope)
            .filter(Proposal.LEGACY_ID.like(code))
            .one_or_none()
        )
    else:  # VLA
        proposal = (
            session.query(Proposal)
            .filter(Proposal.TELESCOPE == telescope)
            .filter(Proposal.PROP_ID.like(code))
            .one_or_none()
        )
    session.close()
    return proposal


def getauthors(telescope, proposalcode):
    code = f"%{proposalcode}%"

    if telescope == "VLBA":
        authors = (
            session.query(Author)
            .join(Proposal, Author.proposal_id == Proposal.proposal_id)
            .join(UserAuthentication, Author.user_id == UserAuthentication.userAuthentication_id)
            .filter(Proposal.TELESCOPE == telescope)
            .filter(Proposal.LEGACY_ID.like(code))
            .all()
        )
    else:  # VLA
        authors = (
            session.query(Author)
            .join(Proposal, Author.proposal_id == Proposal.proposal_id)
            .join(UserAuthentication, Author.user_id == UserAuthentication.userAuthentication_id)
            .filter(Proposal.TELESCOPE == telescope)
            .filter(Proposal.PROP_ID.like(code))
            .all()
        )

    session.close()
    return authors


def getpstuser(globalid):
    user = session.query(Person).filter(text("person_id=:personid")).params(personid=globalid).one()

    return user


def ispi(author):
    if author.proposal.principal_investigator_id == author.author_id:
        return True
    else:
        return False


def main():
    telescope = "VLA"
    proposal_code = "22A-011"
    # telescope = 'VLBA'
    # proposal_code = 'BF132'
    proposal = getproposal(telescope, proposal_code)
    if proposal is not None:
        print(f"Proposal: {proposal.PROP_ID}")
        authors = getauthors(telescope, proposal_code)
        for author in authors:
            print(f"Author: {author.LAST_NAME}")


if __name__ == "__main__":
    main()
