#!/usr/bin/env bash
#
# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
# Helper script to facilitiate bulk ingestion of the VLASS
# quicklook image cache.
#
set -o errexit -o nounset -o xtrace

VLASS_ENV=$(echo $CAPO_PROFILE | sed 's/dsoc-/vlass_/')

# Base Location:
QL_CACHE_DIR=/lustre/aoc/cluster/pipeline/$VLASS_ENV/cache/se_continuum_imaging

# The Epoch:
EPOCH_NAME=$1;shift

# Tile Directory of interest:
SOURCE_SUBDIR=$1;shift

# Build the full path down to the tile:
DIR_TO_PROCESS=${QL_CACHE_DIR}/${EPOCH_NAME}/${SOURCE_SUBDIR}

#
# We need a list of the subdirectories under the tile directory,
# these are the base-level image set containers, so we run image
# ingestion, with the full path:
#
for imageDir in $(ls -1 ${DIR_TO_PROCESS})
do
  vlassQlIngest ${EPOCH_NAME} ${DIR_TO_PROCESS}/${imageDir}
  sleep 60
done
#
