/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, Input, Output, OnInit, EventEmitter } from "@angular/core";
import { decode } from 'hex-encode-decode'
import { CapabilityVersion } from "../../../../model/capability-version";
import { CapabilityRequestService } from "../../../../services/capability-request.service";

@Component({
  selector: "app-files",
  templateUrl: "./files.component.html",
  styleUrls: ["./files.component.scss"],
})
export class FilesComponent implements OnInit {
  @Input() capabilityVersion: CapabilityVersion;
  @Output() editorOpenEventToParent = new EventEmitter<boolean>()

  constructor(private capabilityRequestService: CapabilityRequestService,) {}

  public decodeContent(content: string): string {
    return decode(content)
  }

  private saveEditedContentObserver = {
    next: () => {},
    error: (error) => console.error("Error when saving version file edit:", error),
  };

  catchEditEventFromEditor(filename: string, editedContent: string): void {
    let requestId = this.capabilityVersion.capability_request_id
    this.capabilityRequestService.editVersionFile(requestId, filename, editedContent).subscribe(this.saveEditedContentObserver)
  }

  catchOpenEditorEvent(isEditorOpen: boolean): void{
    this.editorOpenEventToParent.emit(isEditorOpen)
  }

  ngOnInit(): void {}
}
