# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
""" WS-1018: upgrade imaging recipes for masking

Revision ID: 57177960f90a
Revises: ca1f4d78c1a0
Create Date: 2022-04-26 09:39:38.312937

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "57177960f90a"
down_revision = "ca1f4d78c1a0"
branch_labels = None
depends_on = None

old_cms_template_xml = """
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_contimage</ProcedureTitle>
                <ProcessingCommand>
                    <Command xmlns="">hifv_importdata</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_masking</Keyword>
                            <Value xmlns="">none</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">imaging_products_only</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}.ms</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>0
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>
"""

new_cms_template_xml = """
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_contimage</ProcedureTitle>
                <ProcessingCommand>
                    <Command xmlns="">hifv_importdata</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">intents</Keyword>
                            <Value xmlns="">*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*,*UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">quack</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">autocorr</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">baseband</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">edgespw</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">clip</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">online</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">shadow</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">scan</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_pbcor</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                      <Parameter>
                        <Keyword xmlns="">imaging_products_only</Keyword>
                        <Value xmlns="">True</Value>
                      </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}.ms</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>0
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>
"""

old_restore_template_xml = """
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/{{projectCode}}</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents/>
            <ProcessingProcedure>
                <ProcedureTitle>Workspaces Restore Imaging</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_restoredata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_masking</Keyword>
                            <Value xmlns="">none</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">imaging_products_only</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
</ns2:SciPipeRequest>
"""

new_restore_template_xml = """
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/{{projectCode}}</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents/>
            <ProcessingProcedure>
                <ProcedureTitle>Workspaces Restore Imaging</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_restoredata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">intents</Keyword>
                            <Value xmlns="">*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*,*UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">quack</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">autocorr</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">baseband</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">edgespw</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">clip</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">online</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">shadow</Keyword>
                            <Value xmlns="">False</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">scan</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_pbcor</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                      <Parameter>
                        <Keyword xmlns="">imaging_products_only</Keyword>
                        <Value xmlns="">True</Value>
                      </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
</ns2:SciPipeRequest>
"""


def upgrade():
    op.execute(
        f"""
        UPDATE capability_templates SET content=E'{new_cms_template_xml}'
        WHERE filename='PPR.xml' AND capability_name='std_cms_imaging';
    """
    )

    op.execute(
        f"""
        UPDATE capability_templates SET content=E'{new_restore_template_xml}'
        WHERE filename='PPR.xml' AND capability_name='std_restore_imaging';
    """
    )


def downgrade():

    op.execute(
        f"""
        UPDATE capability_templates SET content=E'{old_cms_template_xml}'
        WHERE filename='PPR.xml' AND capability_name='std_cms_imaging';
    """
    )

    op.execute(
        f"""
        UPDATE capability_templates SET content=E'{old_restore_template_xml}'
        WHERE filename='PPR.xml' AND capability_name='std_restore_imaging';
    """
    )
